/***************************************************************************
 * 
 * Copyright (c) 2018 Baidu.com, Inc. All Rights Reserved
 * 
 **************************************************************************/

/**
 * @author ChenXiaoyu
 * @brief demo
 *
 **/

#include <iostream>
#include <sstream>
#include "easyedge/easyedge.h"

using namespace easyedge;

int main(int argc, char *argv[]) {

    if (argc != 3) {
        std::cerr << "Usage: demo {model_dir} {image_name}" << std::endl;
        exit(-1);
    }

    PaddleFluidConfig config;
    config.model_dir = argv[1];
    config.thread_num = 1;
    global_controller()->set_licence_key("set your license here");
    EdgeLogConfig log_config;
    log_config.enable_debug = false;
    global_controller()->set_log_config(log_config);
    auto predictor = global_controller()->CreateEdgePredictor<PaddleFluidConfig>(config);

    if (predictor->init() != EDGE_OK) {
        exit(-1);
    }
    std::stringstream img_path;
    img_path << argv[2];
    auto img = cv::imread(img_path.str());

    std::vector<EdgeResultData> result2;
    predictor->infer(img, result2);

    int top = 0;
    for (auto &v : result2) {
//        if (top++ > 5)
//            break;
        if (v.prob < 0.3) {
            continue;
        }
        std::cout << v.index << ", " << v.label << ", p:" << v.prob;
        if (predictor->model_kind() == EdgeModelKind::kObjectDetection) {
            std::cout << " loc: "
                      << v.x1 << ", " << v.y1 << ", " << v.x2 << ", " << v.y2;
            auto p1 = cv::Point(static_cast<int>(v.x1 * img.cols),
                                static_cast<int>(v.y1 * img.rows));
            auto p2 = cv::Point(static_cast<int>(v.x2 * img.cols),
                                static_cast<int>(v.y2 * img.rows));
            cv::rectangle(img, p1, p2, RED, 2);
            cv::putText(img, v.label, p1, cv::FONT_HERSHEY_PLAIN, 1, BLUE, 2);
        }
        std::cout << std::endl;
    }
    img_path << ".result.jpg";
    std::cout << "Write result to " << img_path.str() << std::endl;
    cv::imwrite(img_path.str(), img);
    std::cout << "Done" << std::endl;
    return 0;
}